==> org.eclipse.rap.rwt.source_1.3.1.20100901-2034.jar: org/eclipse/swt/internal/widgets/ITableAdapter.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 Innoopract Informationssysteme GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Innoopract Informationssysteme GmbH - initial API and implementation
 *     EclipseSource - ongoing development
 ******************************************************************************/
package org.eclipse.swt.internal.widgets;

import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.swt.widgets.TableItem;

public interface ITableAdapter {

  int getCheckWidth();
  int getItemImageWidth( int columnIndex );

  int getFocusIndex();
  void setFocusIndex( int focusIndex );

  int getLeftOffset();
  void setLeftOffset( int leftOffset );

  void checkData();
  void checkData( int index );

  int getColumnLeft( TableColumn column );
  int getDefaultColumnWidth();

  boolean isItemVisible( TableItem item );
  boolean isItemVirtual( int index );
  TableItem[] getCachedItems();
  TableItem[] getCreatedItems();

  boolean hasHScrollBar();
  boolean hasVScrollBar();

  TableItem getMeasureItem();

  ICellToolTipProvider getCellToolTipProvider();
  void setCellToolTipProvider( ICellToolTipProvider provider );

  String getToolTipText();
  void setToolTipText( String toolTipText );
}

==> org.eclipse.rap.rwt.source_1.5.0.20120320-1638.jar: org/eclipse/swt/internal/widgets/ITableAdapter.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2012 Innoopract Informationssysteme GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Innoopract Informationssysteme GmbH - initial API and implementation
 *     EclipseSource - ongoing development
 ******************************************************************************/
package org.eclipse.swt.internal.widgets;

import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.swt.widgets.TableItem;

public interface ITableAdapter {

  int getCheckWidthWithMargin();
  int getCheckWidth();
  int getCheckLeft();
  int getItemImageWidth( int columnIndex );

  int getFocusIndex();
  int getFixedColumns();
  void setFocusIndex( int focusIndex );

  int getColumnLeftOffset( int columnIndex );
  int getLeftOffset();
  void setLeftOffset( int leftOffset );

  void checkData();
  void checkData( int index );

  int getColumnLeft( TableColumn column );
  int getDefaultColumnWidth();

  boolean isItemVisible( TableItem item );
  boolean isItemVirtual( int index );
  TableItem[] getCachedItems();
  TableItem[] getCreatedItems();

  boolean hasHScrollBar();
  boolean hasVScrollBar();

  TableItem getMeasureItem();
  boolean isFixedColumn( TableColumn column );
}
